<?php

namespace Survey\Formms\Policies;

use Litepie\User\Contracts\UserPolicy;
use Survey\Formms\Models\Formms;

class FormmsPolicy
{

    /**
     * Determine if the given user can view the formms.
     *
     * @param UserPolicy $user
     * @param Formms $formms
     *
     * @return bool
     */
    public function view(UserPolicy $user, Formms $formms)
    {
        if ($user->canDo('formms.formms.view') && $user->isAdmin()) {
            return true;
        }

        return $formms->user_id == user_id() && $formms->user_type == user_type();
    }

    /**
     * Determine if the given user can create a formms.
     *
     * @param UserPolicy $user
     * @param Formms $formms
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('formms.formms.create');
    }

    /**
     * Determine if the given user can update the given formms.
     *
     * @param UserPolicy $user
     * @param Formms $formms
     *
     * @return bool
     */
    public function update(UserPolicy $user, Formms $formms)
    {
        if ($user->canDo('formms.formms.edit') && $user->isAdmin()) {
            return true;
        }

        return $formms->user_id == user_id() && $formms->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given formms.
     *
     * @param UserPolicy $user
     * @param Formms $formms
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Formms $formms)
    {
        return $formms->user_id == user_id() && $formms->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given formms.
     *
     * @param UserPolicy $user
     * @param Formms $formms
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Formms $formms)
    {
        if ($user->canDo('formms.formms.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given formms.
     *
     * @param UserPolicy $user
     * @param Formms $formms
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Formms $formms)
    {
        if ($user->canDo('formms.formms.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
